MethodChannelWecomAuthPlus class

An implementation of WecomAuthPlusPlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

auth({String? state}) Future<Map<String, dynamic>>
override
configure({required String scheme, required String corpId, required String agentId}) Future<Map<String, dynamic>>
override
isAppInstalled() Future<Map<String, dynamic>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register({required String scheme, required String corpId, required String agentId}) Future<Map<String, dynamic>>
override
resetAuth() Future<Map<String, dynamic>>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited